#ifndef SYS_DEPS__H__
#define SYS_DEPS__H__
typedef unsigned char uint8;
typedef unsigned short uint16;
typedef unsigned long uint32;
/* sysdep: -ulong64 */
#undef HAS_ULONG64
typedef unsigned long long uint64;
/* sysdep: endian=lsb */
#define ENDIAN_LSB 1
#undef ENDIAN_MSB
#ifndef DIRENTRY_H
#define DIRENTRY_H

#include <sys/types.h>
#include <dirent.h>
#define direntry struct dirent

#endif
#ifndef FORK_H
#define FORK_H

extern int fork();
extern int vfork();

#endif
/* sysdep: +hasflock */
#define HASFLOCK 1

/* sysdep: +struct ucred */
#define HASPEERCRED 1
#include <sys/types.h>
#include <sys/socket.h>
/* sysdep: +linux_sendfile */
#define HASLINUXSENDFILE 1
/* sysdep: +sigaction */
#define HASSIGACTION 1
/* sysdep: +sigprocmask */
#define HASSIGPROCMASK 1
/* sysdep: +hasspnam */
#define HASSPNAM 1
/* sysdep: -hasuserpw */

/* sysdep: +waitpid */
#define HASWAITPID 1
/* sysdep: +haszlib */
#define HASZLIB 1
#ifndef IOPOLL_H
#define IOPOLL_H

/* sysdep: +poll */
#define IOPOLL_POLL

#include <sys/types.h>
#include <poll.h>

typedef struct pollfd iopoll_fd;
#define IOPOLL_READ POLLIN
#define IOPOLL_WRITE POLLOUT
#define iopoll poll

extern int iopoll_restart(iopoll_fd* fds, unsigned nfds, unsigned long timeout);

#endif
#ifndef SELECT_H
#define SELECT_H

/* sysdep: +sysselect */

#include <sys/types.h>
#include <sys/time.h>
#include <sys/select.h>
extern int select();

#endif
/* sysdep: +setenv */
#define HASSETENV 1
#include <stdlib.h>
/* sysdep: +unsetenv */
#define HASUNSETENV 1
/* sysdep: +unaligned */
#define HAS_UNALIGNED_ACCESSES 1
/* These macros are used to produce the declarations and inline
 * definitions for the various uint## pack/unpack msb/lsb functions */

#if defined(__GNUC__) && defined(HAS_UNALIGNED_ACCESSES) && defined(ENDIAN_LSB)
#define __INLINE_UINT_LSB 1
#undef __INLINE_UINT_MSB
#endif

#if defined(__GNUC__) && defined(HAS_UNALIGNED_ACCESSES) && defined(ENDIAN_MSB)
#define __INLINE_UINT_MSB 1
#undef __INLINE_UINT_LSB
#endif

#ifdef __INLINE_UINT_LSB
#define __UINTNN_GET_LSB_DECL(B,N) \
  static __inline__ uint##B uint##B##_get_lsb(const unsigned char b[N]) \
  { return *((const uint##B *)b); }
#define __UINTNN_PACK_LSB_DECL(B,N) \
  static __inline__ void uint##B##_pack_lsb(uint##B u, unsigned char b[N]) \
  { *((uint##B *)b) = u; }
#define __UINTNN_UNPACK_LSB_DECL(B,N) \
  static __inline__ void uint##B##_unpack_lsb(const unsigned char b[N], uint##B *u) \
  { *u = *((uint##B *)b); }
#else
#define __UINTNN_GET_LSB_DECL(B,N) \
  extern uint##B uint##B##_get_lsb(const unsigned char[N]);
#define __UINTNN_PACK_LSB_DECL(B,N) \
  extern void uint##B##_pack_lsb(uint##B, unsigned char[N]);
#define __UINTNN_UNPACK_LSB_DECL(B,N) \
  extern void uint##B##_unpack_lsb(const unsigned char[N], uint##B *);
#endif

#ifdef __INLINE_UINT_MSB
#define __UINTNN_GET_MSB_DECL(B,N) \
  static __inline__ uint##B uint##B##_get_msb(const unsigned char b[N]) \
  { return *((const uint##B *)b); }
#define __UINTNN_PACK_MSB_DECL(B,N) \
  static __inline__ void uint##B##_pack_msb(uint##B u, unsigned char b[N]) \
  { *((uint##B *)b) = u; }
#define __UINTNN_UNPACK_MSB_DECL(B,N) \
  static __inline__ void uint##B##_unpack_msb(const unsigned char b[N], uint##B *u) \
  { *u = *((uint##B *)b); }
#else
#define __UINTNN_GET_MSB_DECL(B,N) \
  extern uint##B uint##B##_get_msb(const unsigned char[N]);
#define __UINTNN_PACK_MSB_DECL(B,N) \
  extern void uint##B##_pack_msb(uint##B, unsigned char[N]);
#define __UINTNN_UNPACK_MSB_DECL(B,N) \
  extern void uint##B##_unpack_msb(const unsigned char[N], uint##B *);
#endif

#define __UINTNN_DECL(B,N) \
  __UINTNN_GET_LSB_DECL(B,N) \
  __UINTNN_PACK_LSB_DECL(B,N) \
  __UINTNN_UNPACK_LSB_DECL(B,N) \
  __UINTNN_GET_MSB_DECL(B,N) \
  __UINTNN_PACK_MSB_DECL(B,N) \
  __UINTNN_UNPACK_MSB_DECL(B,N)

#endif
